
CREATE TABLE BL_SPACE
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(1024),
   DESCRIPTION VARCHAR(4000),
   CREATION_DATE VARCHAR(30) NOT NULL,
   OWNER_DN VARCHAR(400) NOT NULL,
   OWNER_NAME VARCHAR(256) NOT NULL,
   ORG_DN VARCHAR(400) NOT NULL)
	 ;
   
ALTER TABLE BL_SPACE ADD PRIMARY KEY (UUID);

CREATE TABLE BL_TEAM
  (MEMBER_DN VARCHAR(400) NOT NULL,
   MEMBER_CN VARCHAR(128) NOT NULL,
   MEMBER_UID VARCHAR(128) NOT NULL,
   MEMBER_EMAIL VARCHAR(128),
   TYPE INTEGER DEFAULT 0,
   ISOWNER INTEGER DEFAULT 0,
   ISADMIN INTEGER DEFAULT 0,
   SPACE_UUID VARCHAR(256) NOT NULL,
   ORG_DN VARCHAR(400) NOT NULL)
	 ;
   
ALTER TABLE BL_TEAM ADD PRIMARY KEY (MEMBER_DN, SPACE_UUID);

ALTER TABLE BL_TEAM
       ADD CONSTRAINT bl_f_1
              FOREIGN KEY (SPACE_UUID)
                             REFERENCES BL_SPACE  (UUID)
                             ON DELETE CASCADE;

CREATE TABLE BL_FOLDER
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(1024),
   DESCRIPTION VARCHAR(4000),
   PARENT_ID VARCHAR(256) NOT NULL,
   CREATION_DATE VARCHAR(30) NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL)
	 ;
   
ALTER TABLE BL_FOLDER ADD PRIMARY KEY (UUID);
ALTER TABLE BL_FOLDER
       ADD CONSTRAINT bl_f_2
              FOREIGN KEY (SPACE_UUID)
                             REFERENCES BL_SPACE  (UUID)
                             ON DELETE CASCADE;

CREATE TABLE BL_TAGS
  (
   PARENTID VARCHAR(256) NOT NULL,
   DOC_ID VARCHAR(256) NOT NULL,   
   NAME VARCHAR(1024) NOT NULL,   
    VERSION BIGINT NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL,
   MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_TAGS ADD PRIMARY KEY (PARENTID, VERSION);

CREATE TABLE BL_DOC_CONTENT
  (UUID VARCHAR(256) NOT NULL,
   VERSION BIGINT NOT NULL,    
   PUBLICDOC INTEGER DEFAULT 0 NOT NULL,    
   DATA BLOB,	
   MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)   
	 ;

ALTER TABLE BL_DOC_CONTENT ADD PRIMARY KEY (UUID, VERSION, PUBLICDOC);
	 
CREATE TABLE BL_DOCUMENT
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(1024),
   DESCRIPTION VARCHAR(4000),
   TYPE VARCHAR(64) NOT NULL,
   SUBTYPE VARCHAR(64),   
   VERSION BIGINT NOT NULL, 
   SPACE_UUID VARCHAR(256) NOT NULL,
   ORG_DN VARCHAR(400) NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),   
   MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_DOCUMENT ADD PRIMARY KEY (UUID, VERSION);

CREATE TABLE BL_DOC_INFO
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(1024),
   NAMELCASE VARCHAR(1024),
   DESCRIPTION VARCHAR(4000),
   TAGS VARCHAR(1024),
   TAGSLCASE VARCHAR(1024),
   TYPE VARCHAR(64),
   SUBTYPE VARCHAR(64),
   VERSION BIGINT, 
   CREATION_DATE VARCHAR(30) NOT NULL,
   LASTUPDATE VARCHAR(30) NOT NULL,
   LOCKEDBY_DN VARCHAR(400),
   LOCKEDBY_NAME VARCHAR(256),
   LOCKEDBY_SPACE VARCHAR(256),
   LOCKED_DATE VARCHAR(30),
   READONLY SMALLINT DEFAULT 0 NOT NULL,     
   LAST_EDITOR VARCHAR(256),   
   ORG_DN VARCHAR(400) NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),   
   MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)   
	 ;
   
ALTER TABLE BL_DOC_INFO ADD PRIMARY KEY (UUID);

CREATE TABLE BL_DOC_ACL
  (DOC_ID VARCHAR(256) NOT NULL,
   ACL_LEVEL INTEGER DEFAULT 0 NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL)
	 ;

ALTER TABLE BL_DOC_ACL ADD PRIMARY KEY (SPACE_UUID, DOC_ID);

CREATE TABLE BL_DOC_HISTORY
  (VERSION BIGINT NOT NULL,
   NAME VARCHAR(1024),
   DOC_ID VARCHAR(256) NOT NULL,
   TYPE INTEGER DEFAULT 0 NOT NULL,
   USER_DN VARCHAR(400) NOT NULL,
   USER_NAME VARCHAR(256) NOT NULL,
   CREATEDFROM CHAR(30),   
   READONLY SMALLINT DEFAULT 0 NOT NULL,  
   CREATION_DATE VARCHAR(30) NOT NULL)
	 ;
   
ALTER TABLE BL_DOC_HISTORY ADD PRIMARY KEY (DOC_ID, VERSION);

CREATE TABLE BL_DOC_PARENTS
  (DOC_ID VARCHAR(256) NOT NULL,
   PARENT_TYPE VARCHAR(30) NOT NULL,
   PARENT_ID VARCHAR(256) NOT NULL,   
   SPACE_UUID VARCHAR(256) NOT NULL,
   ORG_DN VARCHAR(400) NOT NULL)   
	 ;
   
ALTER TABLE BL_DOC_PARENTS ADD PRIMARY KEY (DOC_ID, PARENT_ID, SPACE_UUID);

ALTER TABLE BL_DOC_PARENTS
       ADD CONSTRAINT bl_f_3
              FOREIGN KEY (SPACE_UUID)
                             REFERENCES BL_SPACE  (UUID)
                             ON DELETE CASCADE;

CREATE TABLE BL_PZDATA
  (USER_DN VARCHAR(400) NOT NULL,
   DOC_ID VARCHAR(256) NOT NULL,
   OPERATION INTEGER NOT NULL, 
   LASTVISIT VARCHAR(30) NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL)
	 ;
   
ALTER TABLE BL_PZDATA ADD PRIMARY KEY (DOC_ID, USER_DN, SPACE_UUID);


CREATE TABLE BL_DOCOWNERSHIPS
  (OWNER_DN VARCHAR(400) NOT NULL,
   OWNER_NAME VARCHAR(256) NOT NULL,
   ISSPACEOWNER INTEGER DEFAULT 0 NOT NULL,
   DOC_ID VARCHAR(256) NOT NULL)
	 ;
   
ALTER TABLE BL_DOCOWNERSHIPS ADD PRIMARY KEY (DOC_ID, OWNER_DN, ISSPACEOWNER);


CREATE TABLE BL_NODE
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(2048),
   NAMELCASE VARCHAR(2048),
   TYPE VARCHAR(64) NOT NULL,
   DESCRIPTION VARCHAR(4000),
   DOC_ID VARCHAR(256) NOT NULL,
   COMENT_COUNT INTEGER DEFAULT 0,
   VERSION BIGINT NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL,
   VISIBILITY SMALLINT DEFAULT 1 NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),
   READONLY SMALLINT DEFAULT 0 NOT NULL,   
   MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_NODE ADD PRIMARY KEY (UUID, VERSION);

CREATE TABLE BL_CHKPT_NODE
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(2048),
   NAMELCASE VARCHAR(2048),
   TYPE VARCHAR(64) NOT NULL,
   DESCRIPTION VARCHAR(4000),
   DESCLCASE VARCHAR(4000),
   DOC_ID VARCHAR(256) NOT NULL,
   VERSION BIGINT NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL,
   VISIBILITY SMALLINT DEFAULT 1 NOT NULL,
   DOC_NAME VARCHAR(1024),
   DOC_TYPE VARCHAR(64) NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),
   READONLY SMALLINT DEFAULT 0 NOT NULL,      
   ORG_DN VARCHAR(400) NOT NULL)
	 ;
   
ALTER TABLE BL_CHKPT_NODE ADD PRIMARY KEY (UUID);

CREATE TABLE BL_PUBLIC_NODE
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(2048),
   NAMELCASE VARCHAR(2048),
   TYPE VARCHAR(64) NOT NULL,
   DESCRIPTION VARCHAR(4000),
   DESCLCASE VARCHAR(4000),
   DOC_ID VARCHAR(256) NOT NULL,
   VERSION BIGINT NOT NULL,
   SPACE_UUID VARCHAR(256) NOT NULL,
   VISIBILITY SMALLINT DEFAULT 1 NOT NULL,
   DOC_NAME VARCHAR(1024),
   DOC_TYPE VARCHAR(64) NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),
   READONLY SMALLINT DEFAULT 0 NOT NULL,      
   ORG_DN VARCHAR(400) NOT NULL)
	 ;	 	 	   

ALTER TABLE BL_PUBLIC_NODE ADD PRIMARY KEY (UUID);   
   
CREATE TABLE BL_ASSOCIATION
  (
  	UUID VARCHAR(256) NOT NULL,
  	SOURCE_DOCID VARCHAR(256) NOT NULL,
  	SOURCE_ID VARCHAR(256) NOT NULL,
  	NAME VARCHAR(256),
  	DESCRIPTION VARCHAR(4000),
  	TYPE VARCHAR(64) NOT NULL,
	VERSION BIGINT NOT NULL,
    SPACE_UUID VARCHAR(256) NOT NULL,
    MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_ASSOCIATION ADD PRIMARY KEY (UUID, VERSION);

CREATE TABLE BL_LINK
  (
  	UUID VARCHAR(256) NOT NULL,
  	ASSOCIATION_ID VARCHAR(256) NOT NULL,
  	SOURCE_DOCID VARCHAR(256) NOT NULL,
  	SOURCE_ID VARCHAR(256) NOT NULL,
  	TARGET_DOCID VARCHAR(256) NOT NULL,
  	TARGET_ID VARCHAR(256) NOT NULL,
  	TYPE VARCHAR(64) NOT NULL,
	VERSION BIGINT NOT NULL,
    SPACE_UUID VARCHAR(256) NOT NULL,
	MANDATORY SMALLINT DEFAULT 0 NOT NULL,
   	T_LOCAL_PART VARCHAR(256),
   	T_NAMESPACE VARCHAR(1024),  
   	T_NSPREFIX VARCHAR(128),  	
    MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_LINK ADD PRIMARY KEY (UUID, VERSION);
   
CREATE TABLE BL_RELATIONSHIP
  (
  	UUID VARCHAR(256) NOT NULL,
  	SOURCE VARCHAR(256) NOT NULL,
  	SOURCETYPE VARCHAR(20) NOT NULL,
  	TARGET VARCHAR(256) NOT NULL,
  	TARGETTYPE VARCHAR(20) NOT NULL,
  	TYPE VARCHAR(64) NOT NULL,
  	NAME VARCHAR(256),
  	DESCRIPTION VARCHAR(4000),
  	ISCONTAINMENT SMALLINT DEFAULT 0 NOT NULL,  	
  	DOC_ID VARCHAR(256) NOT NULL,
	VERSION BIGINT NOT NULL,
    SPACE_UUID VARCHAR(256) NOT NULL,
    MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
   
ALTER TABLE BL_RELATIONSHIP ADD PRIMARY KEY (UUID, VERSION);
	
CREATE TABLE BL_GRPATTRIBUTE
	(UUID VARCHAR(256) NOT NULL,
	PARENT_ID VARCHAR(256) NOT NULL,
	PARENTTYPE VARCHAR(20) NOT NULL,
	TYPE VARCHAR(64) NOT NULL,
	NAME VARCHAR(128),
	DATA VARCHAR(2048),
  	DOC_ID VARCHAR(256) NOT NULL,
    VERSION BIGINT NOT NULL,
   	SPACE_UUID VARCHAR(256) NOT NULL,
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
    
ALTER TABLE BL_GRPATTRIBUTE ADD PRIMARY KEY (UUID, VERSION);	

CREATE TABLE BL_LOBDATA
	(UUID VARCHAR(256) NOT NULL,
	PARENT_ID VARCHAR(256) NOT NULL,
	PARENTTYPE VARCHAR(20) NOT NULL,
	DOC_ID VARCHAR(256) NOT NULL,
	DATA BLOB,	
    VERSION BIGINT NOT NULL,
   	SPACE_UUID VARCHAR(256) NOT NULL,
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
ALTER TABLE BL_LOBDATA ADD PRIMARY KEY (UUID, VERSION);	
	
CREATE TABLE BL_ATTRIBUTE
	(UUID VARCHAR(256) NOT NULL,
	PARENT_ID VARCHAR(256) NOT NULL,
	PARENTTYPE VARCHAR(20) NOT NULL,
	GROUP_ATTRIBUTE_ID VARCHAR(256),
	TYPE VARCHAR(64) NOT NULL,
	NAME VARCHAR(128),
	VALUE VARCHAR(2048),
  	DOC_ID VARCHAR(256) NOT NULL,
	DATATYPE VARCHAR(64) NOT NULL,
	UNITS VARCHAR(64),
	REFOBJECTTYPE VARCHAR(20),
	REFOBJECT_UUID VARCHAR(256),	
    VERSION BIGINT NOT NULL,
   	SPACE_UUID VARCHAR(256) NOT NULL,
	MANDATORY SMALLINT DEFAULT 0 NOT NULL,
	ID VARCHAR(256),
	NAMESPACE VARCHAR(1024),	
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
    
ALTER TABLE BL_ATTRIBUTE ADD PRIMARY KEY (UUID, VERSION);

CREATE TABLE BL_VISUALIZATION
	(UUID VARCHAR(256) NOT NULL,
  	DOC_ID VARCHAR(256) NOT NULL,
	TYPE VARCHAR(64) NOT NULL,
	NAME VARCHAR(128),
    DESCRIPTION VARCHAR(4000),
    VERSION BIGINT NOT NULL,
   	SPACE_UUID VARCHAR(256) NOT NULL,
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
    
ALTER TABLE BL_VISUALIZATION ADD PRIMARY KEY (UUID, VERSION);

CREATE TABLE BL_VISUALATTR
	(UUID VARCHAR(256) NOT NULL,
	PARENT_ID VARCHAR(256) NOT NULL,
	PARENTTYPE VARCHAR(20) NOT NULL,
	VISUALIZATION_ID VARCHAR(256),
	TYPE VARCHAR(64) NOT NULL,
	NAME VARCHAR(128),
	VALUE VARCHAR(2048),
  	DOC_ID VARCHAR(256) NOT NULL,
	DATATYPE VARCHAR(64) NOT NULL,
	UNITS VARCHAR(64),
	REFOBJECTTYPE VARCHAR(20),
    VERSION BIGINT NOT NULL,
   	SPACE_UUID VARCHAR(256) NOT NULL,
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
    
ALTER TABLE BL_VISUALATTR ADD PRIMARY KEY (UUID, VERSION);
	
CREATE TABLE BL_ATTACHMENT
	(ATTACHMENT_KEY VARCHAR(256) NOT NULL,
	ATTACHMENT_NAME VARCHAR(1024) NOT NULL,
	PARENT_ID VARCHAR(256) NOT NULL,
  	DOC_ID VARCHAR(256),
	ATTACHMENT BLOB,
	ATT_SIZE INTEGER NOT NULL,
	ISO_DATE VARCHAR(256) NOT NULL,
	ATTACHMENT_TYPE INTEGER DEFAULT 0 NOT NULL,
	PUBLICDOC INTEGER DEFAULT 0 NOT NULL, 
    VERSION BIGINT NOT NULL,
    FROM_VERSION BIGINT DEFAULT 0 NOT NULL,    
	REFOBJECTTYPE VARCHAR(20),
	REFOBJECT_UUID VARCHAR(256),      
   	SPACE_UUID VARCHAR(256),
   	NAMESPACE VARCHAR(1024),   	
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
ALTER TABLE BL_ATTACHMENT ADD PRIMARY KEY (ATTACHMENT_KEY, VERSION, PUBLICDOC);

CREATE TABLE BL_FILE_REPO
	(UUID VARCHAR(256) NOT NULL,
	NAME VARCHAR(1024) NOT NULL,
	DATA BLOB,
	TYPE SMALLINT DEFAULT 0 NOT NULL,
	FILE_SIZE INTEGER NOT NULL,
	CREATION_DATE TIMESTAMP NOT NULL,
	REF_COUNTER INTEGER NOT NULL,
   	SPACE_UUID VARCHAR(256),
   	MARKFORDELETE INTEGER DEFAULT 0 NOT NULL)
	 ;
    
ALTER TABLE BL_FILE_REPO ADD PRIMARY KEY (UUID);


CREATE TABLE BL_PUBLIC_DOC
  (UUID VARCHAR(256) NOT NULL,
   NAME VARCHAR(1024),
   NAMELCASE VARCHAR(1024),
   DESCRIPTION VARCHAR(4000),
   TAGS VARCHAR(1024),
   TAGSLCASE VARCHAR(1024),
   TYPE VARCHAR(64) NOT NULL,
   SUBTYPE VARCHAR(64),  
   VERSION BIGINT NOT NULL, 
   PUBLISHDATE VARCHAR(30),
   PUBLISHER_DN VARCHAR(400),
   PUBLISHER_NAME VARCHAR(256),
   SPACE_UUID VARCHAR(256) NOT NULL,
   ID VARCHAR(256),
   NAMESPACE VARCHAR(1024),   
   ORG_DN VARCHAR(400) NOT NULL)
	 ;

ALTER TABLE BL_PUBLIC_DOC ADD PRIMARY KEY (UUID);

CREATE TABLE BL_ACL_REQUEST
  (UUID VARCHAR(256) NOT NULL,
   USER_DN VARCHAR(400) NOT NULL,
   USER_CN VARCHAR(256) NOT NULL,
   RESOURCE_UUID VARCHAR(256) NOT NULL,
   RESOURCE_TYPE VARCHAR(30) NOT NULL,
   REQUEST_TYPE VARCHAR(30) NOT NULL,
   REQUEST_STATE VARCHAR(30) NOT NULL,
   CREATION_DATE VARCHAR(30) NOT NULL,
   REQUEST_REASON VARCHAR(1024),
   RESPONSE_REASON VARCHAR(1024),
   SPACE_UUID VARCHAR(256) NOT NULL,
   ORG_DN VARCHAR(400) NOT NULL)
   ;
   
ALTER TABLE BL_ACL_REQUEST ADD PRIMARY KEY (UUID);

CREATE TABLE BL_ENDPOINTS
	(NAME VARCHAR(30) NOT NULL,
	 URL VARCHAR(265) NOT NULL)
	 ;

ALTER TABLE BL_ENDPOINTS ADD PRIMARY KEY (NAME);	 

CREATE TABLE BL_CHKPT_VERSION
	(DOC_ID VARCHAR(265) NOT NULL,
	 VERSION BIGINT NOT NULL)
	 ;

ALTER TABLE BL_CHKPT_VERSION ADD PRIMARY KEY (DOC_ID);

CREATE TABLE BL_CONFIG (
		CONFIG_KEY		VARCHAR(256) NOT NULL,
		CONFIG_VALUE	VARCHAR(64) NOT NULL
)
	 ;

ALTER TABLE BL_CONFIG
		ADD PRIMARY KEY (CONFIG_KEY);